<?php

namespace Laraautos\Accessory\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Laraautos\Accessory\Repositories\Eloquent\Filters\AccessoryPublicFilter;
use Laraautos\Accessory\Repositories\Eloquent\Presenters\AccessoryListPresenter;
use Laraautos\Accessory\Interfaces\AccessoryRepositoryInterface;

class AccessoryPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(AccessoryRepositoryInterface $accessory)
    {
        parent::__construct();
        $this->modules = $this->modules(config('laraautos.accessory.modules'), 'accessory', guard_url('accessory'));
        $this->repository = $accessory;

    }

    /**
     * Show accessory's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(AccessoryPublicFilter::class)
            ->setPresenter(AccessoryListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('accessory::accessory.names'))
            ->view('accessory::public.accessory.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show accessory.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('accessory::accessory.name'))
            ->view('accessory::public.accessory.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
