<?php

namespace Laraautos\Accessory\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Laraautos\Accessory\Models\Accessory;

class AccessoryPolicy
{

    /**
     * Determine if the given user can view the accessory.
     *
     * @param UserPolicyInterface $authUser
     * @param Accessory $accessory
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Accessory $accessory)
    {
        if ($authUser->canDo('accessory.accessory.view') && $authUser->isAdmin()) {
            return true;
        }

        return $accessory->user_id == user_id() && $accessory->user_type == user_type();
    }

    /**
     * Determine if the given user can create a accessory.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('accessory.accessory.create');
    }

    /**
     * Determine if the given user can update the given accessory.
     *
     * @param UserPolicyInterface $authUser
     * @param Accessory $accessory
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Accessory $accessory)
    {
        if ($authUser->canDo('accessory.accessory.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $accessory->user_id == user_id() && $accessory->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given accessory.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Accessory $accessory)
    {
        return $accessory->user_id == user_id() && $accessory->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given accessory.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Accessory $accessory)
    {
        if ($authUser->canDo('accessory.accessory.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given accessory.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Accessory $accessory)
    {
        if ($authUser->canDo('accessory.accessory.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
